import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="numiconveri",
    version="0.1.1",
    author="Torrez",
    author_email="that1.stinkyarmpits@gmail.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PYthonCoder1128/numiconveri",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
    entry_points={"console_scripts": ["numiconveri = numiconveri.__main__:main"]},
)

del setuptools

del long_description
